# Generated by Django 2.2.6 on 2019-11-16 16:43

import castellum.utils.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import parler.fields
import parler.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('auth', '0011_update_proxy_permissions'),
    ]

    operations = [
        migrations.CreateModel(
            name='Study',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=254, verbose_name='Name')),
                ('contact_person', models.CharField(max_length=254, verbose_name='Responsible contact person')),
                ('principal_investigator', models.CharField(max_length=254, verbose_name='Principal Investigator')),
                ('affiliated_scientists', models.CharField(blank=True, max_length=254, verbose_name='Affiliated Scientists')),
                ('affiliated_research_assistants', models.CharField(blank=True, max_length=254, verbose_name='Affiliated Research Assistants')),
                ('description', models.TextField(blank=True, verbose_name='Description')),
                ('keywords', models.CharField(blank=True, max_length=254, verbose_name='Keywords')),
                ('previous_status', models.SmallIntegerField(choices=[(0, 'Edit'), (1, 'Execution'), (2, 'Finished')], default=0, verbose_name='Previous status')),
                ('status', models.SmallIntegerField(choices=[(0, 'Edit'), (1, 'Execution'), (2, 'Finished')], default=0, verbose_name='Status')),
                ('data_sensitivity', models.BooleanField(default=False, verbose_name='Contains sensitive data')),
                ('min_subject_count', models.PositiveIntegerField(blank=True, verbose_name='Required number of subjects')),
                ('expense_allowance', models.PositiveIntegerField(blank=True, null=True, verbose_name='Expense allowance')),
                ('sessions_start', castellum.utils.fields.DateField(blank=True, null=True, verbose_name='Start of test sessions')),
                ('sessions_end', castellum.utils.fields.DateField(blank=True, null=True, verbose_name='End of test sessions')),
                ('exclusion_criteria', models.TextField(blank=True, verbose_name='Inclusion/exclusion criteria')),
                ('recruitment_text', models.TextField(blank=True, verbose_name='Recruitment text')),
                ('domain', models.CharField(default=None, editable=False, max_length=64, unique=True)),
                ('advanced_filtering', models.BooleanField(default=False, help_text='By default you can create only one filtergroup in which all the filters are joined by AND operator. Advanced filtering allows you to create multiple filtergroups which are joined by OR operator.', verbose_name='Advanced filtering')),
                ('custom_filter', models.CharField(blank=True, max_length=254, verbose_name='Custom filter')),
                ('is_exclusive', models.BooleanField(default=False, help_text='When set, this ensures that potential subjects for this study will not be recruited in other studies. Please note that this may hinder other researchers in finding enough participants.', verbose_name='Exclusive subjects')),
                ('complete_matches_only', models.BooleanField(default=False, help_text='By default, filters may include subjects with incomplete attributes. This feature is supposed to improve the quality of the database by asking recruiters to fill missing values on the go. Only allowing complete filter matches can speed up individual recruitments but may deteriorate the quality of the database as a whole. Furthermore, this reduces the number of potential subjects.', verbose_name='Complete filter matches only')),
                ('consent', castellum.utils.fields.RestrictedFileField(blank=True, upload_to='studies/consent/', verbose_name='Consent')),
                ('mail_subject', models.CharField(blank=True, max_length=254, verbose_name='E-mail subject')),
                ('mail_body', models.TextField(blank=True, verbose_name='E-mail body')),
                ('mail_reply_address', models.EmailField(blank=True, max_length=128, verbose_name='Reply e-mail-address')),
                ('excluded_studies', models.ManyToManyField(blank=True, related_name='_study_excluded_studies_+', to='studies.Study', verbose_name='Excluded studies')),
            ],
            options={
                'ordering': ['name'],
                'permissions': [('access_study', 'Can access studies')],
            },
        ),
        migrations.CreateModel(
            name='StudyType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('exclusion_criteria', models.TextField(blank=True, verbose_name='Inclusion/exclusion criteria')),
                ('data_sensitivity', models.BooleanField(default=False, verbose_name='Contains sensitive data')),
            ],
            options={
                'abstract': False,
            },
            bases=(parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='StudySession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('duration', models.PositiveIntegerField(verbose_name='Duration of a session in minutes')),
                ('study', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='studies.Study')),
            ],
        ),
        migrations.CreateModel(
            name='StudyMembership',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('groups', models.ManyToManyField(blank=True, related_name='_studymembership_groups_+', to='auth.Group')),
                ('study', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='studies.Study')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'unique_together': {('study', 'user')},
            },
        ),
        migrations.AddField(
            model_name='study',
            name='members',
            field=models.ManyToManyField(through='studies.StudyMembership', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='study',
            name='study_type',
            field=models.ManyToManyField(blank=True, to='studies.StudyType', verbose_name='Type of study'),
        ),
        migrations.CreateModel(
            name='StudyTypeTranslation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language_code', models.CharField(db_index=True, max_length=15, verbose_name='Language')),
                ('label', models.CharField(max_length=64, verbose_name='Label')),
                ('master', parler.fields.TranslationsForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='studies.StudyType')),
            ],
            options={
                'verbose_name': 'study type Translation',
                'db_table': 'studies_studytype_translation',
                'db_tablespace': '',
                'managed': True,
                'default_permissions': (),
                'unique_together': {('language_code', 'master')},
            },
            bases=(parler.models.TranslatedFieldsModelMixin, models.Model),
        ),
    ]
